==> benchling_api_client-1.1.0a12-py3-none-any.whl: benchling_api_client/v2/alpha/api/apps/update_canvas.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.canvas import Canvas
from ...models.canvas_update import CanvasUpdate
from ...models.forbidden_error import ForbiddenError
from ...models.not_found_error import NotFoundError
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    canvas_id: str,
    json_body: CanvasUpdate,
) -> Dict[str, Any]:
    url = "{}/canvases/{canvas_id}".format(client.base_url, canvas_id=canvas_id)

    headers: Dict[str, Any] = client.get_headers()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[Canvas, ForbiddenError, NotFoundError]]:
    if response.status_code == 200:
        response_200 = Canvas.from_dict(response.json())

        return response_200
    if response.status_code == 403:
        response_403 = ForbiddenError.from_dict(response.json())

        return response_403
    if response.status_code == 404:
        response_404 = NotFoundError.from_dict(response.json())

        return response_404
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[Canvas, ForbiddenError, NotFoundError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    canvas_id: str,
    json_body: CanvasUpdate,
) -> Response[Union[Canvas, ForbiddenError, NotFoundError]]:
    kwargs = _get_kwargs(
        client=client,
        canvas_id=canvas_id,
        json_body=json_body,
    )

    response = httpx.patch(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    canvas_id: str,
    json_body: CanvasUpdate,
) -> Optional[Union[Canvas, ForbiddenError, NotFoundError]]:
    """ Update App Canvas """

    return sync_detailed(
        client=client,
        canvas_id=canvas_id,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    canvas_id: str,
    json_body: CanvasUpdate,
) -> Response[Union[Canvas, ForbiddenError, NotFoundError]]:
    kwargs = _get_kwargs(
        client=client,
        canvas_id=canvas_id,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.patch(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    canvas_id: str,
    json_body: CanvasUpdate,
) -> Optional[Union[Canvas, ForbiddenError, NotFoundError]]:
    """ Update App Canvas """

    return (
        await asyncio_detailed(
            client=client,
            canvas_id=canvas_id,
            json_body=json_body,
        )
    ).parsed

==> benchling_api_client-2.0.41-py3-none-any.whl: benchling_api_client/v2/alpha/api/apps/update_canvas.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.canvas import Canvas
from ...models.canvas_update import CanvasUpdate
from ...models.forbidden_error import ForbiddenError
from ...models.not_found_error import NotFoundError
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    canvas_id: str,
    json_body: CanvasUpdate,
) -> Dict[str, Any]:
    url = "{}/canvases/{canvas_id}".format(client.base_url, canvas_id=canvas_id)

    headers: Dict[str, Any] = client.httpx_client.headers
    headers.update(client.get_headers())

    cookies: Dict[str, Any] = client.httpx_client.cookies
    cookies.update(client.get_cookies())

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[Canvas, ForbiddenError, NotFoundError]]:
    if response.status_code == 200:
        response_200 = Canvas.from_dict(response.json())

        return response_200
    if response.status_code == 403:
        response_403 = ForbiddenError.from_dict(response.json())

        return response_403
    if response.status_code == 404:
        response_404 = NotFoundError.from_dict(response.json())

        return response_404
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[Canvas, ForbiddenError, NotFoundError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    canvas_id: str,
    json_body: CanvasUpdate,
) -> Response[Union[Canvas, ForbiddenError, NotFoundError]]:
    kwargs = _get_kwargs(
        client=client,
        canvas_id=canvas_id,
        json_body=json_body,
    )

    response = client.httpx_client.patch(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    canvas_id: str,
    json_body: CanvasUpdate,
) -> Optional[Union[Canvas, ForbiddenError, NotFoundError]]:
    """ Update App Canvas """

    return sync_detailed(
        client=client,
        canvas_id=canvas_id,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    canvas_id: str,
    json_body: CanvasUpdate,
) -> Response[Union[Canvas, ForbiddenError, NotFoundError]]:
    kwargs = _get_kwargs(
        client=client,
        canvas_id=canvas_id,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.patch(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    canvas_id: str,
    json_body: CanvasUpdate,
) -> Optional[Union[Canvas, ForbiddenError, NotFoundError]]:
    """ Update App Canvas """

    return (
        await asyncio_detailed(
            client=client,
            canvas_id=canvas_id,
            json_body=json_body,
        )
    ).parsed
